@@ -54,6 +54,8 @@ class Federation(object):
         if callable(self.userdb[domain]):
             # A callable was given for the whole domain
             data = self.userdb[domain](domain, user)
+        elif isinstance(self.userdb[domain], dict):
+            data = self.userdb[domain]
         else:
             # Make sure a record exists for the user
             if not user in self.userdb[domain]:
@@ -76,9 +78,10 @@ class Federation(object):
             'federation_json': record
         }
 
-    def error(self, code, msg=None):
+    @classmethod
+    def error(cls, code, msg=None):
         return {
             'result': 'error',
             'error': code,
-            'error_message': msg or self.errors.get(code)
+            'error_message': msg or cls.errors.get(code)
         }
